import React, { useContext, useState, useLayoutEffect } from 'react';
import uuid from 'uuid/v4';
import DirectionContext from './DirectionContext';
export default function useStylesFactory(aesthetic) {
  return function useStyles(styleSheet, customName) {
    if (customName === void 0) {
      customName = 'Component';
    }

    var dir = useContext(DirectionContext);

    var _useState = useState(function () {
      var name = customName + "-" + uuid();
      aesthetic.setStyleSheet(name, styleSheet);
      return name;
    }),
        styleName = _useState[0];

    var options = {
      name: styleName,
      rtl: aesthetic.isRTL(dir)
    };
    var sheet = aesthetic.createStyleSheet(styleName, options);
    useLayoutEffect(function () {
      aesthetic.flushStyles(styleName);
    }, [dir, styleName]);

    var cx = function cx() {
      for (var _len = arguments.length, styles = new Array(_len), _key = 0; _key < _len; _key++) {
        styles[_key] = arguments[_key];
      }

      return aesthetic.transformStyles(styles, options);
    };

    return [sheet, cx, styleName];
  };
}