"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var v4_1 = __importDefault(require("uuid/v4"));
var DirectionContext_1 = __importDefault(require("./DirectionContext"));
/**
 * Hook within a component to provide a style sheet.
 */
function useStylesFactory(aesthetic) {
    return function useStyles(styleSheet, customName) {
        if (customName === void 0) { customName = 'Component'; }
        var dir = react_1.useContext(DirectionContext_1.default);
        var styleName = react_1.useState(function () {
            var name = customName + "-" + v4_1.default();
            aesthetic.registerStyleSheet(name, styleSheet);
            return name;
        })[0];
        // Create a unique style sheet for this component
        var options = { name: styleName, rtl: aesthetic.isRTL(dir) };
        var sheet = aesthetic.createStyleSheet(styleName, options);
        // Flush styles on mount
        react_1.useLayoutEffect(function () {
            aesthetic.flushStyles(styleName);
        }, [dir, styleName]);
        // Create a CSS transformer
        var cx = function () {
            var styles = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                styles[_i] = arguments[_i];
            }
            return aesthetic.transformStyles(styles, options);
        };
        return [sheet, cx, styleName];
    };
}
exports.default = useStylesFactory;
